import ttkbootstrap as tb
import ttkbootstrap.constants
from tkinter import messagebox
import requests
import json

# Global variable to store the access token
access_token = None

def login_frame(parent, switch_func, api_url):
    frame = tb.Frame(parent)

    def login():
        global access_token
        email = entry_email.get()
        password = entry_password.get()

        if not email or not password:
            messagebox.showwarning("Input Error", "Both fields are required!")
            return

        response = requests.post(
            f"{api_url}/auth/login", json={"email": email, "password": password}
        )

        try:
            response_data = response.json()
            if response.status_code == 200:
                access_token = response_data.get("access_token")
                print(f"Access Token: {access_token}")  # Debugging line

                # Save the access token to a file
                with open("access_token.json", "w") as token_file:
                    json.dump({"access_token": access_token}, token_file)

                messagebox.showinfo("Login Successful", f"Welcome back, {email}!")
                switch_func("create_shop")
            else:
                messagebox.showerror(
                    "Login Failed", response_data.get("detail", "Invalid credentials")
                )
        except requests.exceptions.JSONDecodeError:
            messagebox.showerror("Login Failed", "Server returned an invalid response.")

    tb.Label(frame, text="Login", font=("Helvetica", 18, "bold")).pack(pady=10)

    tb.Label(frame, text="Email:").pack(pady=5)
    entry_email = tb.Entry(frame, bootstyle="info")
    entry_email.pack(pady=5)

    tb.Label(frame, text="Password:").pack(pady=5)
    entry_password = tb.Entry(frame, bootstyle="info", show="*")
    entry_password.pack(pady=5)

    btn_login = tb.Button(frame, text="Login", bootstyle="primary", command=login)
    btn_login.pack(pady=15)

    tb.Button(
        frame,
        text="Don't have an account? Register",
        bootstyle="link",
        command=lambda: switch_func("register"),
    ).pack()

    return frame